from Accuinsight.Lifecycle import keras
from Accuinsight.Lifecycle import tensorflow
#	20220613 move gitlab repo


class Lifecycle:
    """
    The exposed class to user
    """
    def __init__(self):
        self.accu_keras = keras.accuinsight()
        self.accu_tensorflow = tensorflow.accuinsight()

    def run_keras(self, tag=None):
        self.accu_keras.autolog(tag)

    def run_tensorflow(self, tag=None):
        self.accu_tensorflow.autolog(tag)



from __future__ import print_function
import os
import sys
import json
import subprocess
from Accuinsight.modeler.core.LcConst import LcConst

_BASH_RC_PATH = '/home/notebook/.bashrc'


def get_os_env(env_type='LC', env_path=None, env_file=None):
    _ENV_PREFIX = env_type + '_'

    env_value = {}
    if env_path is None:
        env_path = '/usr'
    if env_file is None:
        env_file = '.accu_env'

    env_file = open(env_path + '/' + env_file, 'r')
    while True:
        line = env_file.readline()
        if not line:
            break

        if _ENV_PREFIX in line:
            key, value = line.split('=')
            if key is not None:
                if _ENV_PREFIX in key:
                    value = value.rstrip()
                    env_value.setdefault(key, value)

    return env_value


def is_in_ipython():
    return 'ipykernel_launcher.py' in sys.argv[0]


def get_current_notebook():
    if is_in_ipython():
        target_path = LcConst.ENV_JUPYTER_WORKSPACE
        # '/home/notebook/.jupyter/lab/workspaces'
        if os.path.isdir(target_path):  # if jupyter lab
            file_lists = list()
            file_name = None
            for (dir_path, dir_names, file_names) in os.walk(target_path):
                for fn in file_names:
                    #                    print(fn)
                    #                    print(": ",os.path.getmtime(target_path+"/"+fn))
                    if not fn.endswith('.swp'):
                        file_lists[fn] = os.path.getmtime(target_path + "/" + fn)
            print(file_lists)
            sorted_file_lists_modified = sorted(file_lists.items(), key=lambda item: item[1], reverse=True)
            print(sorted_file_lists_modified)
            file_name = sorted_file_lists_modified[0][0]
            print(file_name)
            # 원본 소스
            # for (dir_path, dir_names, file_names) in os.walk(target_path):
            #     for fn in file_names:
            #         if not fn.endswith('.swp'):
            #             if 'default' in fn:
            #                 file_name = fn
            #                 break
            #             file_lists.append(fn)
            #
            # if not file_name:
            #     file_name = file_lists[0]

            with open(target_path + '/' + file_name, 'r') as tf:
                strlines = tf.readlines()
                json_file = json.loads(strlines[0])
                return json_file['data']['layout-restorer:data']['main']['current'].split(':')[1]
        else:
            subprocess.check_call([sys.executable, "-m", "pip", "install", 'ipyparams'])
            import ipyparams
            return ipyparams.notebook_name



from collections.abc import Mapping
from csv import DictReader
import json
from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, RUN_MODEL_VISUAL_CSV_PATH, \
    RUN_MODEL_VISUAL_JSON_PATH, RUN_MODEL_JSON_PATH, SELECTED_METRICS
from Accuinsight.modeler.protos.life_cycle_pb2 import LcMetric, LcParam
from Accuinsight.modeler.core.Run.ParseRun import Parse_Helper

# get parameter path with run type
# get metric path with run type


def load_parameter(run_meta):
    run_result_path = run_meta[RUN_RESULT_PATH]
    json_path = run_result_path[RUN_MODEL_JSON_PATH]

    with open(json_path) as json_file:
        param_json_data = json.load(json_file)

    return param_json_data


def load_visual_json(run_meta):
    run_result_path = run_meta[RUN_RESULT_PATH]
    json_path = run_result_path[RUN_MODEL_VISUAL_JSON_PATH]

    with open(json_path) as json_file:
        param_json_data = json.load(json_file)

    return param_json_data


def _read_csv_with_csv(run_meta):
    column_dict = {}

    run_result_path = run_meta[RUN_RESULT_PATH]
    csv_path = run_result_path[RUN_MODEL_VISUAL_CSV_PATH]

    with open(csv_path, 'r') as read_csv:
        csv_dict_reader = DictReader(read_csv, delimiter=';')
        column_names = csv_dict_reader.fieldnames

        for row in csv_dict_reader:
            for col_name in column_names:
                column_dict.setdefault(col_name, []).append(row[col_name])

    return column_dict


def load_metric(run_meta):
    column_dict = _read_csv_with_csv(run_meta)

    result_dict = {'metrics': []}
    for key in column_dict:
        if key != 'epoch':
            result_dict['metrics'].append({'key': key, 'values': column_dict[key], 'timestamp': column_dict['epoch'], 'steps': column_dict['epoch']})

    return result_dict


def _append_metrics(metrics, **kwargs):
    values = []
    timestamp = []
    steps = []
    count = 0
    data = kwargs['data']
    key = kwargs['key']

    for v in data:
        values.append(str(v))
        timestamp.append(str(count))
        steps.append(str(count))
        count += 1
    metrics.append({'key': key,
                    'values': values,
                    'timestamp': timestamp,
                    'steps': steps})
    return metrics


def _parse_true_predict(metrics, run_meta):
    param_data = load_visual_json(run_meta)
    true_y = []
    predicted_y = []
    true_y_values = param_data['True_y']
    predicted_y_values = param_data['Predicted_y']

    # check if nested list
    is_nested_true = any(isinstance(elem, list) for elem in true_y_values)
    is_nested_predicted = any(isinstance(elem, list) for elem in predicted_y_values)

    if is_nested_true:
        for elem in true_y_values:
            true_y.append(elem[0])
    else:
        true_y = true_y_values

    if is_nested_predicted:
        for elem in predicted_y_values:
            predicted_y.append(elem[0])
    else:
        predicted_y = predicted_y_values

    metrics = _append_metrics(metrics, data=true_y, key='true_y')
    metrics = _append_metrics(metrics, data=predicted_y, key='predicted_y')
    return metrics


# parse metrics
def _parse_selected_metrics(run_meta):
    # read ~/runs/results-XGBClassifier/model-info-json/*.json
    # get "selected_metrics" field
    # return metrics

    metric_data = load_parameter(run_meta)

    grpc_metrics = []
    if SELECTED_METRICS not in metric_data:
        return grpc_metrics

    # selected_metrics
    selected_metrics = metric_data[SELECTED_METRICS]
    metric_keys = selected_metrics.keys()

    result_dict = {'metrics': []}

    count = 0
    timestamp = []
    steps = []
    values = []
    for key in metric_keys:
        values.append(str(selected_metrics[key]))
        timestamp.append(str(count))
        steps.append(key)
        count += 1

    result_dict['metrics'].append({
                                   'values': values,
                                   'timestamp': timestamp,
                                   'steps': steps})

    metrics = result_dict['metrics']

    for item in metrics:
        metric = LcMetric(
                key=SELECTED_METRICS,
                values=item['values'],
                timestamp=item['timestamp'],
                steps=item['steps']
            )
        grpc_metrics.append(metric)

    return grpc_metrics


def parse_metric(run_meta):
    metric_data = load_metric(run_meta)
    metrics = metric_data['metrics']
    metrics = _parse_true_predict(metrics, run_meta)

    grpc_metrics = []

    for item in metrics:
        metric = LcMetric(
                key=item['key'],
                values=item['values'],
                timestamp=item['timestamp'],
                steps=item['steps']
            )
        grpc_metrics.append(metric)

    selected_metrics = _parse_selected_metrics(run_meta=run_meta)
    grpc_metrics = grpc_metrics + selected_metrics
    return grpc_metrics


def _parse_optimizer_info(param_data):
    grpc_params = []
    data_version = Parse_Helper.get_data_version(param_data)
    grpc_params.append(data_version)

    optimizer_info = param_data['optimizer_info']
    if isinstance(optimizer_info, Mapping):
        for k, v in optimizer_info.items():
            optimizer = LcParam(
                key='type_of_optimizer',
                value=str(k)
            )
            grpc_params.append(optimizer)
            if isinstance(v, Mapping):
                for k, v in v.items():
                    param = LcParam(
                        key=k,
                        value=str(v)
                    )
                    grpc_params.append(param)
    return grpc_params


def parse_parameter(run_meta):
    param_data = load_parameter(run_meta)

    dummy_data = {
        'model_description': 'keras test',
        'logging_time': '2020-05-06 10:30:50',
        'run_id': '9FCEF776-D830-4353-8961-144491DC03CC',
        'model_type': 'keras_nn',
        'optimizer_info': {
            'RMSprop': {
                'learning_rate': 9.999999747378752e-05,
                'rho': 0.8999999761581421,
                'decay': 0.0,
                'epsilon': 1e-07
            }
        },
        'time_delta': '0:00:14.912202'
    }

    return _parse_optimizer_info(param_data)


def parse_run_result(run_info_json):
    result_dict = {'metrics': None, 'params': None, 'visual': None}

    metric_data = parse_metric(run_meta=run_info_json)
    parameter_data = parse_parameter(run_meta=run_info_json)
    for i in range(len(parameter_data)):
        if parameter_data[i].key == 'data_version':
            result_dict['artifact'] = {}
            result_dict['artifact']['name'] = parameter_data[i].value
            result_dict['artifact']['version'] = ""
            del parameter_data[i]
            break

    result_dict['params'] = parameter_data
    result_dict['metrics'] = metric_data
    return result_dict




import os
import argparse
import subprocess
import re
from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
from Accuinsight.modeler.entities.workspace_run_log import WorkspaceRunLog
from Accuinsight.modeler.core.LcConst import LcConst
from Accuinsight.modeler.utils.os_getenv import get_os_env


class WorkspaceRun:
    """
        Object for running code and sending the result to backend.
    """
    def __init__(self):
        env_value = get_os_env('ENV')

        self.workspace_run_log = WorkspaceRunLog()
        self.workspace_run_api = WorkspaceRestApi(env_value[LcConst.BACK_END_API_URL],
                                                  env_value[LcConst.BACK_END_API_PORT],
                                                  env_value[LcConst.BACK_END_API_URI])
        self.code_path = None
        self.custom_args = ''

    def exec_code(self):
        parser = argparse.ArgumentParser()
        parser.add_argument('--workspaceRunId', default=None)
        parser.add_argument('--codePath', default=None)
        parser.add_argument('--argument', default='')

        args, unknown = parser.parse_known_args()
        args_dict = vars(args)

        # set custom arguments
        if not args_dict['argument'] == '':
            self.custom_args = ' ' + args_dict['argument']\
                .replace('[[:space:]]', ' ').replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')

        special_char_check = self.custom_args.strip()

        if special_char_check.startswith("'") and special_char_check.endswith("'"):
            self.custom_args = self.custom_args.translate(self.custom_args.maketrans({"'": None}))
            # Regex Special Chars
            regex = re.compile('[@!$%^&()|]')
            # Convert Space-Separated String to List
            argument_list = self.custom_args.split()
            tmp_custom_args = ""

            for arg in argument_list:
                if (regex.search(arg) != None):
                    input_arg = "'%s'" % arg
                else:
                    input_arg = arg
                tmp_custom_args = "%s %s" % (tmp_custom_args, input_arg)
            self.custom_args = tmp_custom_args
        else:
            print("Not matched argument formats from workspaceRun-shell")

        self.code_path = args_dict['codePath']
        self.workspace_run_log.workspace_run_id = args_dict['workspaceRunId']

        if not self.code_path:
            raise Exception("codePath cannot be none")

        new_env = os.environ.copy()
        new_env['PATH'] = '/opt/conda/bin:' + new_env['PATH']

        try:
            # python run with subprocess
            subprocess.run("/opt/conda/bin/python -u '%s'%s > /tmp/output_%s.log 2>&1" %
                           (self.code_path, self.custom_args, self.workspace_run_log.workspace_run_id),
                           shell=True, encoding='UTF-8', env=new_env).check_returncode()
            self.workspace_run_log.is_success = True

            # add success log
            with open("/tmp/output_%s.log" % self.workspace_run_log.workspace_run_id, 'a') as result_log:
                result_log.write("\nWorkspace run with id=%s has been successfully finished.\n" %
                                 self.workspace_run_log.workspace_run_id)

        except subprocess.CalledProcessError:
            # if failed
            self.workspace_run_log.is_success = False
        finally:
            # call backend api (afterRun)
            self.workspace_run_api.call_rest_api(self.workspace_run_log.get_result_param(), 'run')


if __name__ == "__main__":
    workspace_run = WorkspaceRun()
    workspace_run.exec_code()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: life_cycle.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import skapi_pb2 as skapi__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='life_cycle.proto',
  package='modeler',
  syntax='proto2',
  serialized_options=_b('\220\001\001'),
  serialized_pb=_b('\n\x10life_cycle.proto\x12\x07modeler\x1a\x0bskapi.proto\"\x9a\x03\n\x0bLcCreateRun\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0e\n\x06userId\x18\x04 \x01(\t\x12\x13\n\x0blanguage_id\x18\x05 \x01(\t\x12\x1f\n\x03run\x18\n \x01(\x0b\x32\x12.modeler.LcRunInfo\x12%\n\x08\x61rtifact\x18\x0b \x01(\x0b\x32\x13.modeler.LcArtifact\x12\x1f\n\x03git\x18\x0c \x01(\x0b\x32\x12.modeler.LcGitInfo\x12#\n\tparameter\x18\r \x03(\x0b\x32\x10.modeler.LcParam\x12\"\n\x07metrics\x18\x0e \x03(\x0b\x32\x11.modeler.LcMetric\x12\"\n\x07visuals\x18\x0f \x03(\x0b\x32\x11.modeler.LcVisual\x12&\n\ndependency\x18\x10 \x01(\x0b\x32\x12.modeler.LcPyDepen\x1a\'\n\x08Response\x12\x1b\n\x03run\x18\x01 \x01(\x0b\x32\x0e.modeler.LcRun\"\x19\n\tLcPyDepen\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\xd0\x01\n\tLcRunInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06userId\x18\x02 \x01(\t\x12\x0e\n\x06\x63reaDt\x18\x03 \x01(\x03\x12\r\n\x05\x65ndDt\x18\x04 \x01(\x03\x12\x10\n\x08\x64uration\x18\x05 \x01(\x03\x12\r\n\x05\x61\x66Loc\x18\x06 \x01(\t\x12$\n\x06status\x18\x07 \x01(\x0e\x32\x14.modeler.LcRunStatus\x12\x0c\n\x04note\x18\t \x01(\t\x12\x0c\n\x04path\x18\x0b \x01(\t\x12\x11\n\tmodelPath\x18\x0c \x01(\t\x12\x10\n\x08jsonPath\x18\r \x01(\t\"+\n\nLcArtifact\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"(\n\tLcGitInfo\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x02 \x01(\t\"\x86\x01\n\x0bLcCreateTag\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\x15\n\rexperiment_id\x18\x03 \x01(\t\x12\x0e\n\x06run_id\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\t\x1a\n\n\x08Response\"\x17\n\x05LcRun\x12\x0e\n\x06run_id\x18\x01 \x01(\t\"I\n\x08LcMetric\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\x12\x11\n\ttimestamp\x18\x03 \x03(\t\x12\r\n\x05steps\x18\x04 \x03(\t\"\x91\x01\n\x08LcVisual\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\nlistValues\x18\x02 \x03(\x0b\x32\x1b.modeler.ListOfListOfValues\x12%\n\x06values\x18\x03 \x03(\x0b\x32\x15.modeler.ListOfValues\x12\x11\n\ttimestamp\x18\x04 \x03(\t\x12\r\n\x05steps\x18\x05 \x03(\t\":\n\x12ListOfListOfValues\x12$\n\x06values\x18\x01 \x03(\x0b\x32\x14.modeler.FloatValues\"\x1d\n\x0b\x46loatValues\x12\x0e\n\x06values\x18\x01 \x03(\x02\"\x1e\n\x0cListOfValues\x12\x0e\n\x06values\x18\x01 \x03(\t\"%\n\x07LcParam\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t*Y\n\x0bLcRunStatus\x12\r\n\tLcRUNNING\x10\x01\x12\x0f\n\x0bLcSCHEDULED\x10\x02\x12\x0e\n\nLcFINISHED\x10\x03\x12\x0c\n\x08LcFAILED\x10\x04\x12\x0c\n\x08LcKILLED\x10\x05\x32\x80\x03\n\x10LifecycleService\x12\xae\x01\n\x0blcCreateRun\x12\x14.modeler.LcCreateRun\x1a\x1d.modeler.LcCreateRun.Response\"j\xf2\x86\x19\x66\nV\n\x04POST\x12H/project/{project}/workspace/{workspaceId}/experiment/{experimentId}/run\x1a\x04\x08\x02\x10\x00\x10\x01*\nCreate Run\x12\xba\x01\n\x0blcCreateTag\x12\x14.modeler.LcCreateTag\x1a\x1d.modeler.LcCreateTag.Response\"v\xf2\x86\x19r\nb\n\x04POST\x12T/project/{project}/workspace/{workspaceId}/experiment/{experimentId}/run/{runId}/tag\x1a\x04\x08\x02\x10\x00\x10\x01*\nCreate RunB\x03\x90\x01\x01')
  ,
  dependencies=[skapi__pb2.DESCRIPTOR,])

_LCRUNSTATUS = _descriptor.EnumDescriptor(
  name='LcRunStatus',
  full_name='modeler.LcRunStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LcRUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LcSCHEDULED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LcFINISHED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LcFAILED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LcKILLED', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1327,
  serialized_end=1416,
)
_sym_db.RegisterEnumDescriptor(_LCRUNSTATUS)

LcRunStatus = enum_type_wrapper.EnumTypeWrapper(_LCRUNSTATUS)
LcRUNNING = 1
LcSCHEDULED = 2
LcFINISHED = 3
LcFAILED = 4
LcKILLED = 5



_LCCREATERUN_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='modeler.LcCreateRun.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='modeler.LcCreateRun.Response.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=453,
)

_LCCREATERUN = _descriptor.Descriptor(
  name='LcCreateRun',
  full_name='modeler.LcCreateRun',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='modeler.LcCreateRun.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='modeler.LcCreateRun.workspace_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='modeler.LcCreateRun.experiment_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userId', full_name='modeler.LcCreateRun.userId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run', full_name='modeler.LcCreateRun.run', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact', full_name='modeler.LcCreateRun.artifact', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='git', full_name='modeler.LcCreateRun.git', index=7,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='modeler.LcCreateRun.parameter', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='modeler.LcCreateRun.metrics', index=9,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visuals', full_name='modeler.LcCreateRun.visuals', index=10,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dependency', full_name='modeler.LcCreateRun.dependency', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LCCREATERUN_RESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=453,
)


_LCPYDEPEN = _descriptor.Descriptor(
  name='LcPyDepen',
  full_name='modeler.LcPyDepen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='modeler.LcPyDepen.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=480,
)


_LCRUNINFO = _descriptor.Descriptor(
  name='LcRunInfo',
  full_name='modeler.LcRunInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='modeler.LcRunInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userId', full_name='modeler.LcRunInfo.userId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creaDt', full_name='modeler.LcRunInfo.creaDt', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endDt', full_name='modeler.LcRunInfo.endDt', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='modeler.LcRunInfo.duration', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='afLoc', full_name='modeler.LcRunInfo.afLoc', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='modeler.LcRunInfo.status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='note', full_name='modeler.LcRunInfo.note', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='modeler.LcRunInfo.path', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modelPath', full_name='modeler.LcRunInfo.modelPath', index=9,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='jsonPath', full_name='modeler.LcRunInfo.jsonPath', index=10,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=691,
)


_LCARTIFACT = _descriptor.Descriptor(
  name='LcArtifact',
  full_name='modeler.LcArtifact',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='modeler.LcArtifact.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='modeler.LcArtifact.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=693,
  serialized_end=736,
)


_LCGITINFO = _descriptor.Descriptor(
  name='LcGitInfo',
  full_name='modeler.LcGitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='modeler.LcGitInfo.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit', full_name='modeler.LcGitInfo.commit', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=778,
)


_LCCREATETAG_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='modeler.LcCreateTag.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=424,
)

_LCCREATETAG = _descriptor.Descriptor(
  name='LcCreateTag',
  full_name='modeler.LcCreateTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project_id', full_name='modeler.LcCreateTag.project_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='modeler.LcCreateTag.workspace_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='modeler.LcCreateTag.experiment_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_id', full_name='modeler.LcCreateTag.run_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='modeler.LcCreateTag.key', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='modeler.LcCreateTag.value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LCCREATETAG_RESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=915,
)


_LCRUN = _descriptor.Descriptor(
  name='LcRun',
  full_name='modeler.LcRun',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='run_id', full_name='modeler.LcRun.run_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=917,
  serialized_end=940,
)


_LCMETRIC = _descriptor.Descriptor(
  name='LcMetric',
  full_name='modeler.LcMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='modeler.LcMetric.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='modeler.LcMetric.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='modeler.LcMetric.timestamp', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steps', full_name='modeler.LcMetric.steps', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=942,
  serialized_end=1015,
)


_LCVISUAL = _descriptor.Descriptor(
  name='LcVisual',
  full_name='modeler.LcVisual',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='modeler.LcVisual.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listValues', full_name='modeler.LcVisual.listValues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='modeler.LcVisual.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='modeler.LcVisual.timestamp', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='steps', full_name='modeler.LcVisual.steps', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1163,
)


_LISTOFLISTOFVALUES = _descriptor.Descriptor(
  name='ListOfListOfValues',
  full_name='modeler.ListOfListOfValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='modeler.ListOfListOfValues.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1223,
)


_FLOATVALUES = _descriptor.Descriptor(
  name='FloatValues',
  full_name='modeler.FloatValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='modeler.FloatValues.values', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1225,
  serialized_end=1254,
)


_LISTOFVALUES = _descriptor.Descriptor(
  name='ListOfValues',
  full_name='modeler.ListOfValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='modeler.ListOfValues.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1286,
)


_LCPARAM = _descriptor.Descriptor(
  name='LcParam',
  full_name='modeler.LcParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='modeler.LcParam.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='modeler.LcParam.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1288,
  serialized_end=1325,
)

_LCCREATERUN_RESPONSE.fields_by_name['run'].message_type = _LCRUN
_LCCREATERUN_RESPONSE.containing_type = _LCCREATERUN
_LCCREATERUN.fields_by_name['run'].message_type = _LCRUNINFO
_LCCREATERUN.fields_by_name['artifact'].message_type = _LCARTIFACT
_LCCREATERUN.fields_by_name['git'].message_type = _LCGITINFO
_LCCREATERUN.fields_by_name['parameter'].message_type = _LCPARAM
_LCCREATERUN.fields_by_name['metrics'].message_type = _LCMETRIC
_LCCREATERUN.fields_by_name['visuals'].message_type = _LCVISUAL
_LCCREATERUN.fields_by_name['dependency'].message_type = _LCPYDEPEN
_LCRUNINFO.fields_by_name['status'].enum_type = _LCRUNSTATUS
_LCCREATETAG_RESPONSE.containing_type = _LCCREATETAG
_LCVISUAL.fields_by_name['listValues'].message_type = _LISTOFLISTOFVALUES
_LCVISUAL.fields_by_name['values'].message_type = _LISTOFVALUES
_LISTOFLISTOFVALUES.fields_by_name['values'].message_type = _FLOATVALUES
DESCRIPTOR.message_types_by_name['LcCreateRun'] = _LCCREATERUN
DESCRIPTOR.message_types_by_name['LcPyDepen'] = _LCPYDEPEN
DESCRIPTOR.message_types_by_name['LcRunInfo'] = _LCRUNINFO
DESCRIPTOR.message_types_by_name['LcArtifact'] = _LCARTIFACT
DESCRIPTOR.message_types_by_name['LcGitInfo'] = _LCGITINFO
DESCRIPTOR.message_types_by_name['LcCreateTag'] = _LCCREATETAG
DESCRIPTOR.message_types_by_name['LcRun'] = _LCRUN
DESCRIPTOR.message_types_by_name['LcMetric'] = _LCMETRIC
DESCRIPTOR.message_types_by_name['LcVisual'] = _LCVISUAL
DESCRIPTOR.message_types_by_name['ListOfListOfValues'] = _LISTOFLISTOFVALUES
DESCRIPTOR.message_types_by_name['FloatValues'] = _FLOATVALUES
DESCRIPTOR.message_types_by_name['ListOfValues'] = _LISTOFVALUES
DESCRIPTOR.message_types_by_name['LcParam'] = _LCPARAM
DESCRIPTOR.enum_types_by_name['LcRunStatus'] = _LCRUNSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LcCreateRun = _reflection.GeneratedProtocolMessageType('LcCreateRun', (_message.Message,), dict(

  Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
    DESCRIPTOR = _LCCREATERUN_RESPONSE,
    __module__ = 'life_cycle_pb2'
    # @@protoc_insertion_point(class_scope:modeler.LcCreateRun.Response)
    ))
  ,
  DESCRIPTOR = _LCCREATERUN,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcCreateRun)
  ))
_sym_db.RegisterMessage(LcCreateRun)
_sym_db.RegisterMessage(LcCreateRun.Response)

LcPyDepen = _reflection.GeneratedProtocolMessageType('LcPyDepen', (_message.Message,), dict(
  DESCRIPTOR = _LCPYDEPEN,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcPyDepen)
  ))
_sym_db.RegisterMessage(LcPyDepen)

LcRunInfo = _reflection.GeneratedProtocolMessageType('LcRunInfo', (_message.Message,), dict(
  DESCRIPTOR = _LCRUNINFO,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcRunInfo)
  ))
_sym_db.RegisterMessage(LcRunInfo)

LcArtifact = _reflection.GeneratedProtocolMessageType('LcArtifact', (_message.Message,), dict(
  DESCRIPTOR = _LCARTIFACT,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcArtifact)
  ))
_sym_db.RegisterMessage(LcArtifact)

LcGitInfo = _reflection.GeneratedProtocolMessageType('LcGitInfo', (_message.Message,), dict(
  DESCRIPTOR = _LCGITINFO,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcGitInfo)
  ))
_sym_db.RegisterMessage(LcGitInfo)

LcCreateTag = _reflection.GeneratedProtocolMessageType('LcCreateTag', (_message.Message,), dict(

  Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
    DESCRIPTOR = _LCCREATETAG_RESPONSE,
    __module__ = 'life_cycle_pb2'
    # @@protoc_insertion_point(class_scope:modeler.LcCreateTag.Response)
    ))
  ,
  DESCRIPTOR = _LCCREATETAG,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcCreateTag)
  ))
_sym_db.RegisterMessage(LcCreateTag)
_sym_db.RegisterMessage(LcCreateTag.Response)

LcRun = _reflection.GeneratedProtocolMessageType('LcRun', (_message.Message,), dict(
  DESCRIPTOR = _LCRUN,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcRun)
  ))
_sym_db.RegisterMessage(LcRun)

LcMetric = _reflection.GeneratedProtocolMessageType('LcMetric', (_message.Message,), dict(
  DESCRIPTOR = _LCMETRIC,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcMetric)
  ))
_sym_db.RegisterMessage(LcMetric)

LcVisual = _reflection.GeneratedProtocolMessageType('LcVisual', (_message.Message,), dict(
  DESCRIPTOR = _LCVISUAL,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcVisual)
  ))
_sym_db.RegisterMessage(LcVisual)

ListOfListOfValues = _reflection.GeneratedProtocolMessageType('ListOfListOfValues', (_message.Message,), dict(
  DESCRIPTOR = _LISTOFLISTOFVALUES,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.ListOfListOfValues)
  ))
_sym_db.RegisterMessage(ListOfListOfValues)

FloatValues = _reflection.GeneratedProtocolMessageType('FloatValues', (_message.Message,), dict(
  DESCRIPTOR = _FLOATVALUES,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.FloatValues)
  ))
_sym_db.RegisterMessage(FloatValues)

ListOfValues = _reflection.GeneratedProtocolMessageType('ListOfValues', (_message.Message,), dict(
  DESCRIPTOR = _LISTOFVALUES,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.ListOfValues)
  ))
_sym_db.RegisterMessage(ListOfValues)

LcParam = _reflection.GeneratedProtocolMessageType('LcParam', (_message.Message,), dict(
  DESCRIPTOR = _LCPARAM,
  __module__ = 'life_cycle_pb2'
  # @@protoc_insertion_point(class_scope:modeler.LcParam)
  ))
_sym_db.RegisterMessage(LcParam)


DESCRIPTOR._options = None

_LIFECYCLESERVICE = _descriptor.ServiceDescriptor(
  name='LifecycleService',
  full_name='modeler.LifecycleService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1419,
  serialized_end=1803,
  methods=[
  _descriptor.MethodDescriptor(
    name='lcCreateRun',
    full_name='modeler.LifecycleService.lcCreateRun',
    index=0,
    containing_service=None,
    input_type=_LCCREATERUN,
    output_type=_LCCREATERUN_RESPONSE,
    serialized_options=_b('\362\206\031f\nV\n\004POST\022H/project/{project}/workspace/{workspaceId}/experiment/{experimentId}/run\032\004\010\002\020\000\020\001*\nCreate Run'),
  ),
  _descriptor.MethodDescriptor(
    name='lcCreateTag',
    full_name='modeler.LifecycleService.lcCreateTag',
    index=1,
    containing_service=None,
    input_type=_LCCREATETAG,
    output_type=_LCCREATETAG_RESPONSE,
    serialized_options=_b('\362\206\031r\nb\n\004POST\022T/project/{project}/workspace/{workspaceId}/experiment/{experimentId}/run/{runId}/tag\032\004\010\002\020\000\020\001*\nCreate Run'),
  ),
])
_sym_db.RegisterServiceDescriptor(_LIFECYCLESERVICE)

DESCRIPTOR.services_by_name['LifecycleService'] = _LIFECYCLESERVICE

LifecycleService = service_reflection.GeneratedServiceType('LifecycleService', (_service.Service,), dict(
  DESCRIPTOR = _LIFECYCLESERVICE,
  __module__ = 'life_cycle_pb2'
  ))

LifecycleService_Stub = service_reflection.GeneratedServiceStubType('LifecycleService_Stub', (LifecycleService,), dict(
  DESCRIPTOR = _LIFECYCLESERVICE,
  __module__ = 'life_cycle_pb2'
  ))


# @@protoc_insertion_point(module_scope)



'''
<2020.05.13>
Classify available loss functions to regression and classification.

reference: https://www.tensorflow.org/api_docs/python/tf/keras/losses
total: 34
'''

REGRESSION = ['MeanAbsoluteError', 'MeanAbsolutePercentageError', 'MeanSquaredError', 'MeanSquaredError', 'MAE', 'mae', 'MAPE', 'mape', 'MSE', 'mse', 'MSLE', 'msle', 'Huber', 'huber', 'LogCosh','logcosh', 'Poisson', 'poisson']
CLASSIFICATION = ['Hinge', 'hinge', 'SquaredHinge', 'squared_hinge', 'KLD', 'KLDivergence', 'BinaryCrossentropy', 'binary_crossentropy', 'CategoricalCrossentropy', 'CategoricalHinge', 'categorical_crossentropy', 'categorical_hinge', 'SparseCategoricalCrossentropy', 'sparse_categorical_crossentropy']

# poisson: regression for count data

# These are not loss functions.
# (Reduction / serialize / deserialize / get / Loss)



from Accuinsight.__about__ import __author__, __url__, __version__


def modelerInfo():
    return ("mlcc information: version: %s, author: %s, url: %s" \
            % (__version__, __author__, __url__))
